@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertCodeOutput;
 
-our $DATE = '2018-04-06'; # DATE
-our $VERSION = '0.040'; # VERSION
+our $DATE = '2019-02-04'; # DATE
+our $VERSION = '0.041'; # VERSION
 
 use 5.010001;
 use strict;
@@ -31,7 +31,8 @@ sub munge_file {
     my ($self, $file) = @_;
     my $content = $file->content;
     if ($content =~ s{^#\s*CODE:\s*(.*)\s*$}{$self->_code_output($1)."\n"}egm) {
-        $self->log(["inserting output of code '%s' in %s: '%s'", $1, $file->name, $content]);
+        $self->log(["inserting output of code '%s' in %s", $1, $file->name]);
+        $self->log_debug(["output of code: %s", $content]);
         $file->content($content);
     }
 }
@@ -69,7 +70,7 @@ Dist::Zilla::Plugin::InsertCodeOutput - Insert the output of Perl code into your
 
 =head1 VERSION
 
-This document describes version 0.040 of Dist::Zilla::Plugin::InsertCodeOutput (from Perl distribution Dist-Zilla-Plugin-InsertCodeOutput), released on 2018-04-06.
+This document describes version 0.041 of Dist::Zilla::Plugin::InsertCodeOutput (from Perl distribution Dist-Zilla-Plugin-InsertCodeOutput), released on 2019-02-04.
 
 =head1 SYNOPSIS
 
@@ -126,7 +127,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
